@@ -12,7 +12,6 @@
 #include <botan/types.h>
 #include <botan/secmem.h>
 #include <botan/exceptn.h>
-#include <botan/loadstor.h>
 #include <iosfwd>
 
 namespace Botan {
@@ -137,6 +136,8 @@ class BOTAN_PUBLIC_API(2,0) BigInt final
         this->swap(other);
         }
 
+     ~BigInt() { const_time_unpoison(); }
+
      /**
      * Move assignment
      */
@@ -497,11 +498,7 @@ class BOTAN_PUBLIC_API(2,0) BigInt final
      * @param n the offset to get a byte from
      * @result byte at offset n
      */
-     uint8_t byte_at(size_t n) const
-        {
-        return get_byte(sizeof(word) - (n % sizeof(word)) - 1,
-                        word_at(n / sizeof(word)));
-        }
+     uint8_t byte_at(size_t n) const;
 
      /**
      * Return the word at a specified position of the internal register
@@ -642,7 +639,7 @@ class BOTAN_PUBLIC_API(2,0) BigInt final
      * Resize the vector to the minimum word size to hold the integer, or
      * min_size words, whichever is larger
      */
-     void shrink_to_fit(size_t min_size = 0)
+     void BOTAN_DEPRECATED("Use resize if required") shrink_to_fit(size_t min_size = 0)
         {
         m_data.shrink_to_fit(min_size);
         }
@@ -725,6 +722,11 @@ class BOTAN_PUBLIC_API(2,0) BigInt final
      */
      void ct_cond_swap(bool predicate, BigInt& other);
 
+     /**
+     * If predicate is true add value to *this
+     */
+     void ct_cond_add(bool predicate, const BigInt& value);
+
      /**
      * If predicate is true flip the sign of *this
      */
@@ -948,7 +950,11 @@ class BOTAN_PUBLIC_API(2,0) BigInt final
               {
               invalidate_sig_words();
               if(i >= m_reg.size())
+                 {
+                 if(w == 0)
+                    return;
                  grow_to(i + 1);
+                 }
               m_reg[i] = w;
               }
 
@@ -983,7 +989,7 @@ class BOTAN_PUBLIC_API(2,0) BigInt final
                  {
                  const word mask = (static_cast<word>(1) << (n % BOTAN_MP_WORD_BITS)) - 1;
                  const size_t len = size() - (top_word + 1);
-                 if (len > 0)
+                 if(len > 0)
                     {
                     clear_mem(&m_reg[top_word+1], len);
                     }
